==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/gu.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'gu', {
	button: {
		title: 'બટનના ગુણ',
		text: 'ટેક્સ્ટ (વૅલ્યૂ)',
		type: 'પ્રકાર',
		typeBtn: 'બટન',
		typeSbm: 'સબ્મિટ',
		typeRst: 'રિસેટ'
	},
	checkboxAndRadio: {
		checkboxTitle: 'ચેક બોક્સ ગુણ',
		radioTitle: 'રેડિઓ બટનના ગુણ',
		value: 'વૅલ્યૂ',
		selected: 'સિલેક્ટેડ'
	},
	form: {
		title: 'ફૉર્મ/પત્રકના ગુણ',
		menu: 'ફૉર્મ/પત્રકના ગુણ',
		action: 'ક્રિયા',
		method: 'પદ્ધતિ',
		encoding: 'અન્કોડીન્ગ'
	},
	hidden: {
		title: 'ગુપ્ત ક્ષેત્રના ગુણ',
		name: 'નામ',
		value: 'વૅલ્યૂ'
	},
	select: {
		title: 'પસંદગી ક્ષેત્રના ગુણ',
		selectInfo: 'સૂચના',
		opAvail: 'ઉપલબ્ધ વિકલ્પ',
		value: 'વૅલ્યૂ',
		size: 'સાઇઝ',
		lines: 'લીટીઓ',
		chkMulti: 'એકથી વધારે પસંદ કરી શકો',
		opText: 'ટેક્સ્ટ',
		opValue: 'વૅલ્યૂ',
		btnAdd: 'ઉમેરવું',
		btnModify: 'બદલવું',
		btnUp: 'ઉપર',
		btnDown: 'નીચે',
		btnSetValue: 'પસંદ કરલી વૅલ્યૂ સેટ કરો',
		btnDelete: 'રદ કરવું'
	},
	textarea: {
		title: 'ટેક્સ્ટ એઅરિઆ, શબ્દ વિસ્તારના ગુણ',
		cols: 'કૉલમ/ઊભી કટાર',
		rows: 'પંક્તિઓ'
	},
	textfield: {
		title: 'ટેક્સ્ટ ફીલ્ડ, શબ્દ ક્ષેત્રના ગુણ',
		name: 'નામ',
		value: 'વૅલ્યૂ',
		charWidth: 'કેરેક્ટરની પહોળાઈ',
		maxChars: 'અધિકતમ કેરેક્ટર',
		type: 'ટાઇપ',
		typeText: 'ટેક્સ્ટ',
		typePass: 'પાસવર્ડ',
		typeEmail: 'Email', // MISSING
		typeSearch: 'Search', // MISSING
		typeTel: 'Telephone Number', // MISSING
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.6+dfsg.orig.tar.xz: ckeditor-dev-4.5.6/plugins/forms/lang/gu.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'gu', {
	button: {
		title: 'બટનના ગુણ',
		text: 'ટેક્સ્ટ (વૅલ્યૂ)',
		type: 'પ્રકાર',
		typeBtn: 'બટન',
		typeSbm: 'સબ્મિટ',
		typeRst: 'રિસેટ'
	},
	checkboxAndRadio: {
		checkboxTitle: 'ચેક બોક્સ ગુણ',
		radioTitle: 'રેડિઓ બટનના ગુણ',
		value: 'વૅલ્યૂ',
		selected: 'સિલેક્ટેડ',
		required: 'Required' // MISSING
	},
	form: {
		title: 'ફૉર્મ/પત્રકના ગુણ',
		menu: 'ફૉર્મ/પત્રકના ગુણ',
		action: 'ક્રિયા',
		method: 'પદ્ધતિ',
		encoding: 'અન્કોડીન્ગ'
	},
	hidden: {
		title: 'ગુપ્ત ક્ષેત્રના ગુણ',
		name: 'નામ',
		value: 'વૅલ્યૂ'
	},
	select: {
		title: 'પસંદગી ક્ષેત્રના ગુણ',
		selectInfo: 'સૂચના',
		opAvail: 'ઉપલબ્ધ વિકલ્પ',
		value: 'વૅલ્યૂ',
		size: 'સાઇઝ',
		lines: 'લીટીઓ',
		chkMulti: 'એકથી વધારે પસંદ કરી શકો',
		required: 'Required', // MISSING
		opText: 'ટેક્સ્ટ',
		opValue: 'વૅલ્યૂ',
		btnAdd: 'ઉમેરવું',
		btnModify: 'બદલવું',
		btnUp: 'ઉપર',
		btnDown: 'નીચે',
		btnSetValue: 'પસંદ કરલી વૅલ્યૂ સેટ કરો',
		btnDelete: 'રદ કરવું'
	},
	textarea: {
		title: 'ટેક્સ્ટ એઅરિઆ, શબ્દ વિસ્તારના ગુણ',
		cols: 'કૉલમ/ઊભી કટાર',
		rows: 'પંક્તિઓ'
	},
	textfield: {
		title: 'ટેક્સ્ટ ફીલ્ડ, શબ્દ ક્ષેત્રના ગુણ',
		name: 'નામ',
		value: 'વૅલ્યૂ',
		charWidth: 'કેરેક્ટરની પહોળાઈ',
		maxChars: 'અધિકતમ કેરેક્ટર',
		required: 'Required', // MISSING
		type: 'ટાઇપ',
		typeText: 'ટેક્સ્ટ',
		typePass: 'પાસવર્ડ',
		typeEmail: 'Email', // MISSING
		typeSearch: 'Search', // MISSING
		typeTel: 'Telephone Number', // MISSING
		typeUrl: 'URL'
	}
} );
